@@ -1,8 +1,8 @@
 #######################################
 #   program:  pyimgsort.py
 #   author:  x.seeks
-#   version:  0.13dev
-#   date:  2010-08-05
+#   version:  0.15
+#   date:  2010-08-12
 #   description:  Sorts images into
 #   separate directories by apect ratio
 ########################################
@@ -18,9 +18,17 @@ import platform
 
 
 
+
+# These are used later
+countlist = []
+badcountlist = []
+
 ## Some color code initially borrowed from linux-image-writer.py
 ##  These are all bolded
 
+# First, it detects if the platform is Windows.  If it is, the colors are
+# set to nothing because the "DOS prompt" (cmd) can't display these colors.
+
 platformname = platform.system()
 
 if platformname == "Windows":
@@ -42,37 +50,43 @@ else:
 
 ## The following makes a list of the files in 'x', then sets the
 ## the current working directory to 'workdir'.  It then sends the files list
-## to 'validate(x)'.
+## to 'validate(x)', and then tells imgcount to print.  This function is
+## probably the main go-to guy for the module.
      
 def getfiles(x):
     """ Makes a list of files in 'x', then changes the cwd to 'workdir' """
     workdir = str(x)
     os.chdir(workdir)
-    for root, dirs, files in os.walk('%s' % workdir):
-        validate(files)
+    filelist = os.listdir(os.getcwd())
+    for x in filelist:
+        validate(x)
+    count = countlist.count(1)
+    badcount = badcountlist.count(1)
+    imgcount(count, badcount)
+    #print badcount
 
 
-## The following tries opening every file in the list (in this case, cleverly
-## named "files").  For everything that's not an image file, it won't open
-## and tells the user that it's not an image.
+## The following tries tries opening whatever file was sent to it by
+## by getfiles(x).  If the file is valid, it's sent to filer(x)  This function
+## also tallies the number of valid and invalid files processed.
 
 def validate(x):
     """ 
-    This sends valid files to be processed in filer(x), and passes over files  that aren't images 
+    This sends valid files to be processed in filer(x), and passes over files  that aren't images.  It also tallies the number of either type processed.
     """
     validfiles = []
-    for infile in x:
-        imgfile = open(infile, "rb")
-        try:
-            im = Image.open(imgfile)
-            validfiles.append(infile)
-            imgfile.close()
-            del im
-        except IOError:
-            pass
-            imgfile.close()
+    try:
+        imgfile = open(x, "rb")
+        im = Image.open(imgfile)
+        validfiles.append(x)
+        countlist.append(1)
+        imgfile.close()
+        del im
+    except IOError:
+        badcountlist.append(1)
+        pass
     if validfiles != []:
-        filer(validfiles)
+        filer(x)
 
             
 ##  The following checks for the existence of directory 'x'.  If 'x' does
@@ -90,45 +104,41 @@ def dir_check(x):
         
 
 ##  This sorts the image files according to their dimensions, and then sends
-##  them on their way to the mover function.  It also tallies the total number
-##  of images processed and sends that number to 'imgcount(x)'.
+##  them on their way to the mover function.
 
 def filer(x):
     """
-     Sorts images according to orientation, sending them to their respective filer:  filer_landscape(x) or filer_portrait(x).  This function also tallies images processed and sends the total to imgcount(x) 
+     Sorts images according to orientation, sending them to their respective filer:  filer_landscape(x), filer_portrait(x), or filer_square(x). 
      """
     portrait = []
     landscape = []
-    count = 0
-    for image in x:
-        imgfile = open(image, "rb")
-        img = Image.open(imgfile)
-        w,h = img.size
-        w = float(w)
-        h = float(h)
-        ratio = w / h
-        del img
-        imgfile.close()
-        if ratio > 1:
-            landscape.append(image)
-            count += 1
-        else:
-            portrait.append(image)
-            count += 1
-    filer_landscape(landscape)
-    filer_portrait(portrait)
-    imgcount(count)
+    imgfile = open(x, "rb")
+    img = Image.open(imgfile)
+    w,h = img.size
+    w = float(w)
+    h = float(h)
+    ratio = w / h
+    del img
+    imgfile.close()
+    if ratio > 1:
+        filer_landscape(x)
+    elif ratio < 1:
+        filer_portrait(x)
+    elif ratio == 1:
+        filer_square(x)
   
 
 ##  This prints the number of images successfully processed.  'x' was counted
-##  in 'filer(x)'.
+##  in 'filer(x)'  It also prints the number of non-images that were ignored.
 
-def imgcount(x):
-    """ Prints the number of images processed """
+def imgcount(x,y):
+    """ Prints the number of images processed, and non-images ignored """
     print '\n' * 2
     print '-' * 15
     print COLOR_LG, '%d images sorted.' % x, COLOR_BLACK
     print '-' * 15
+    print COLOR_YELLOW, '%d files ignored.' % y, COLOR_BLACK
+    print '-' * 15
     print '\n' * 2
     
 
@@ -139,72 +149,91 @@ def imgcount(x):
 ##  'dir_check' function) as specified in 'filer_landscape(x)' or
 ##  'filer_portrait(x)'.
 
-def mover(image, ratio, w, h, res):
+def mover(x, ratio, w, h, res):
     """ 
     This runs the dir_check(x) function, then moves the files as specified in either filer_landscape(x) or filer_portrait(x)
      """
-    print COLOR_LB, '%s : ' % image, COLOR_YELLOW, '[%d x %d]' % (int(w), int(h)), COLOR_BLACK + '=', '%s' % res, COLOR_BLACK,'=' * 5 + '>', COLOR_LC, '%s' % ratio, COLOR_BLACK
+    print COLOR_LB, '%s : ' % x, COLOR_YELLOW, '[%d x %d]' % (int(w), int(h)), COLOR_BLACK + '=', '%s' % res, COLOR_BLACK,'=' * 5 + '>', COLOR_LC, '%s' % ratio, COLOR_BLACK
     dir_check(ratio)
-    shutil.move(image, './%s/%s' % (ratio, image))
+    shutil.move(x, './%s/%s' % (ratio, x))
     
 
 
+## This files square images, sending them to the mover.
+
+def filer_square(x):
+    """
+    This files square images, sending them to the mover.
+    """
+    imgfile = open(x, "rb")
+    img = Image.open(imgfile)
+    w,h = img.size
+    w = float(w)
+    h = float(h)
+    ratio = '1-1'
+    res = '1:1 (Square)'
+    del img
+    imgfile.close()
+    mover(x, ratio, w, h, res)
+    
+    
 ##  This is the filer for landscape-oriented images.  If the image meets
 ##  certain criteria, it's sent to 'mover(image, ratio, w, h, res)', along
 ##  with the appropriate arguments.
+
+
 def filer_landscape(x):
     """ 
     Sorts landscape-oriented images according to aspect ratio, sending the results to mover(image, ratio, w, h, res) to do the actual moving. 
     """
-    for image in x:
-        imgfile = open(image, "rb")
-        img = Image.open(imgfile)
-        w,h = img.size
-        w = float(w)
-        h = float(h)
-        ratio = w / h
-        del img
-        imgfile.close()
-        if ratio == 1.6:
-            ratio = '16-10'
-            res = '16:10'
-            mover(image, ratio, w, h, res)
-        elif ratio > 1.7 and ratio <= 1.79:
-            ratio = '16-9'
-            res = '16:9'
-            mover(image, ratio, w, h, res)
-        elif ratio >= 1.3 and ratio < 1.4:
-            ratio = '4-3'
-            res = '4:3'
-            mover(image, ratio, w, h, res)
-        elif ratio > 1.48 and ratio <= 1.5:
-            ratio = '3-2'
-            res = '3:2'
-            mover(image, ratio, w, h, res)
-        elif ratio == 1.25:
-            ratio = '5-4'
-            res = '5:4'
-            mover(image, ratio, w, h, res)
-        elif ratio > 1.64 and ratio < 1.66:
-            ratio = '1_66-1'
-            res = '1.66:1'
-            mover(image, ratio, w, h, res)
-        elif ratio > 1.66 and ratio < 1.7:
-            ratio = '5-3'
-            res = '5:3'
-            mover(image, ratio, w, h, res)
-        elif ratio > 1.8 and ratio <= 1.85:
-            ratio = '1_85-1'
-            res = '1.85:1'
-            mover(image, ratio, w, h, res)
-        elif ratio > 2.37 and ratio <= 2.4:
-            ratio = '2_39-1'
-            res = '2.39:1'
-            mover(image, ratio, w, h, res)
-        else:
-            ratio = 'misc_landscape'
-            res = 'misc (landscape)'
-            mover(image, ratio, w, h, res)
+    imgfile = open(x, "rb")
+    img = Image.open(imgfile)
+    w,h = img.size
+    w = float(w)
+    h = float(h)
+    ratio = w / h
+    del img
+    imgfile.close()
+    if ratio == 1.6:
+        ratio = '16-10'
+        res = '16:10'
+        mover(x, ratio, w, h, res)
+    elif ratio > 1.7 and ratio <= 1.79:
+        ratio = '16-9'
+        res = '16:9'
+        mover(x, ratio, w, h, res)
+    elif ratio >= 1.3 and ratio < 1.4:
+        ratio = '4-3'
+        res = '4:3'
+        mover(x, ratio, w, h, res)
+    elif ratio > 1.48 and ratio <= 1.5:
+        ratio = '3-2'
+        res = '3:2'
+        mover(x, ratio, w, h, res)
+    elif ratio == 1.25:
+        ratio = '5-4'
+        res = '5:4'
+        mover(x, ratio, w, h, res)
+    elif ratio > 1.64 and ratio < 1.66:
+        ratio = '1_66-1'
+        res = '1.66:1'
+        mover(x, ratio, w, h, res)
+    elif ratio > 1.66 and ratio < 1.7:
+        ratio = '5-3'
+        res = '5:3'
+        mover(x, ratio, w, h, res)
+    elif ratio > 1.8 and ratio <= 1.85:
+        ratio = '1_85-1'
+        res = '1.85:1'
+        mover(x, ratio, w, h, res)
+    elif ratio > 2.37 and ratio <= 2.4:
+        ratio = '2_39-1'
+        res = '2.39:1'
+        mover(x, ratio, w, h, res)
+    else:
+        ratio = 'misc_landscape'
+        res = 'misc (landscape)'
+        mover(x, ratio, w, h, res)
 			
 
 ##  This is the filer for portrait-oriented images.  If the image meets
@@ -217,55 +246,54 @@ def filer_portrait(x):
     Sorts landscape-oriented images according to aspect ratio, sending the results to mover(image, ratio, w, h, res) to do the actual moving. 
     """
     
-    for image in x:
-        imgfile = open(image, "rb")
-        img = Image.open(imgfile)
-        w,h = img.size
-        w = float(w)
-        h = float(h)
-        ratio = h / w
-        del img
-        imgfile.close()
-        if ratio == 1.6:
-            ratio = '16-10_p'
-            res = '16:10 (portrait)'
-            mover(image, ratio, w, h, res)
-        elif ratio > 1.7 and ratio <= 1.79:
-            ratio = '16-9_p'
-            res = '16:9 (portrait)'
-            mover(image, ratio, w, h, res)
-        elif ratio >= 1.3 and ratio < 1.4:
-            ratio = '4-3_p'
-            res = '4:3 (portrait)'
-            mover(image, ratio, w, h, res)
-        elif ratio > 1.48 and ratio <= 1.5:
-            ratio = '3-2_p'
-            res = '3:2 (portrait)'
-            mover(image, ratio, w, h, res)
-        elif ratio == 1.25:
-            ratio = '5-4_p'
-            res = '5:4 (portrait)'
-            mover(image, ratio, w, h, res)
-        elif ratio > 1.64 and ratio < 1.66:
-            ratio = '1_66-1_p'
-            res = '1.66:1 (portrait)'
-            mover(image, ratio, w, h, res)
-        elif ratio > 1.66 and ratio < 1.7:
-            ratio = '5-3_p'
-            res = '5:3 (portrait)'
-            mover(image, ratio, w, h, res)
-        elif ratio > 1.8 and ratio <= 1.85:
-            ratio = '1_85-1_p'
-            res = '1.85:1 (portrait)'
-            mover(image, ratio, w, h, res)
-        elif ratio > 2.37 and ratio <= 2.4:
-            ratio = '2_39-1_p'
-            res = '2.39:1 (portrait)'
-            mover(image, ratio, w, h, res)
-        else:
-            ratio = 'misc_portrait'
-            res = 'misc (portrait)'
-            mover(image, ratio, w, h, res)
+    imgfile = open(x, "rb")
+    img = Image.open(imgfile)
+    w,h = img.size
+    w = float(w)
+    h = float(h)
+    ratio = h / w
+    del img
+    imgfile.close()
+    if ratio == 1.6:
+        ratio = '16-10_p'
+        res = '16:10 (portrait)'
+        mover(x, ratio, w, h, res)
+    elif ratio > 1.7 and ratio <= 1.79:
+        ratio = '16-9_p'
+        res = '16:9 (portrait)'
+        mover(x, ratio, w, h, res)
+    elif ratio >= 1.3 and ratio < 1.4:
+        ratio = '4-3_p'
+        res = '4:3 (portrait)'
+        mover(x, ratio, w, h, res)
+    elif ratio > 1.48 and ratio <= 1.5:
+        ratio = '3-2_p'
+        res = '3:2 (portrait)'
+        mover(x, ratio, w, h, res)
+    elif ratio == 1.25:
+        ratio = '5-4_p'
+        res = '5:4 (portrait)'
+        mover(x, ratio, w, h, res)
+    elif ratio > 1.64 and ratio < 1.66:
+        ratio = '1_66-1_p'
+        res = '1.66:1 (portrait)'
+        mover(x, ratio, w, h, res)
+    elif ratio > 1.66 and ratio < 1.7:
+        ratio = '5-3_p'
+        res = '5:3 (portrait)'
+        mover(x, ratio, w, h, res)
+    elif ratio > 1.8 and ratio <= 1.85:
+        ratio = '1_85-1_p'
+        res = '1.85:1 (portrait)'
+        mover(x, ratio, w, h, res)
+    elif ratio > 2.37 and ratio <= 2.4:
+        ratio = '2_39-1_p'
+        res = '2.39:1 (portrait)'
+        mover(x, ratio, w, h, res)
+    else:
+        ratio = 'misc_portrait'
+        res = 'misc (portrait)'
+        mover(x, ratio, w, h, res)
 			
 			
 ##  This asks the user for a directory to sort if no argument was
